@@ -1,10 +1,6 @@
 #ifndef CLPEAK_HPP
 #define CLPEAK_HPP
 
-#define __CL_ENABLE_EXCEPTIONS
-
-#include <CL/cl.hpp>
-
 #include <iostream>
 #include <stdio.h>
 #include <iomanip>
@@ -22,7 +18,7 @@ class clPeak
 public:
 
   bool forcePlatform, forceDevice, useEventTimer;
-  bool isGlobalBW, isComputeSP, isComputeDP, isComputeInt, isTransferBW, isKernelLatency;
+  bool isGlobalBW, isComputeSP, isComputeDP, isComputeIntFast, isComputeInt, isTransferBW, isKernelLatency;
   ulong specifiedPlatform, specifiedDevice;
   logger *log;
 
@@ -44,6 +40,8 @@ public:
 
   int runComputeInteger(cl::CommandQueue &queue, cl::Program &prog, device_info_t &devInfo);
 
+  int runComputeIntFast(cl::CommandQueue &queue, cl::Program &prog, device_info_t &devInfo);
+
   int runTransferBandwidthTest(cl::CommandQueue &queue, cl::Program &prog, device_info_t &devInfo);
 
   int runKernelLatency(cl::CommandQueue &queue, cl::Program &prog, device_info_t &devInfo);
